@@ -1,6 +1,8 @@
 import argparse
+import os
 
 from impactrun import fuzzallspecs, runall
+from impactrun.runconfig import inspecdir
 
 
 def main():
@@ -11,6 +13,11 @@ def main():
     parser.add_argument('-u', '--customer-name', help='customer name (optional)', default='N/A')
     args = parser.parse_args()
 
+    for filename in os.listdir(inspecdir):
+        if ' ' in filename:
+            print('WARNING: Spaces are not allowed in spec filename. Replacing spaces with underscore')
+            os.rename(os.path.join(inspecdir, filename), os.path.join(inspecdir, filename.replace(' ', '_')))
+
     if args.generate_tests:
         fuzzallspecs.fuzzspecs()
     elif args.execute_tests or args.regen_report:
