@@ -84,6 +84,8 @@ def extractAPITests(attack, severity, inreport, inainfo):
         s = tname[len("test_"):]
         method = s[:s.find("_")]
         api = s[s.find("_") + 1:s.find("_for_fuzzing")].replace("__", "/").replace("9i9", "-")
+        if '/' not in api:
+            api = '/' + api
         if "call" not in onetest:
             continue
         # outcome can be pass/failed/skipped
