@@ -13,7 +13,7 @@
 # \***************************************************************/
 
 from base64 import encode
-import collections
+from collections.abc import Mapping
 import datetime
 import json
 import os
@@ -68,7 +68,7 @@ def update_nested_dict(key, value, dictionary):
 
 def keypaths(nested):
     for key, value in nested.items():
-        if isinstance(value, collections.Mapping):
+        if isinstance(value, Mapping):
             for subkey, subvalue in keypaths(value):
                 yield [key] + subkey, subvalue
         else:
